@@ -9,7 +9,7 @@
 #include <gtk/gtk.h>
 
 #ifndef gbool
-# define gbool	guchar
+# define gbool	gboolean
 #endif
 
 /*
@@ -17,10 +17,10 @@
  */
 typedef struct {
 
-	gbool initialized;
-	gbool map_state;
+	gboolean initialized;
+	gboolean map_state;
 
-	void *core_ptr;
+	gpointer core_ptr;
 
 	GtkWidget *toplevel;
 	GtkWidget *main_label;
