@@ -25,15 +25,15 @@ static int EditorFileLoadProgressCB(
 	long cur, long max, void *data
 );
 static int EditorFileSaveProgressCB(
-        long cur, long max, void *data
+	long cur, long max, void *data
 );
 
 static void EditorFileLoadParseTitleHeading(
-        editor_struct *editor, const char *line_ptr,
-        editor_item_struct *item_ptr
+	editor_struct *editor, const char *line_ptr,
+	editor_item_struct *item_ptr
 );
 static void EditorFileLoadParseHeader(
-        editor_struct *editor, editor_item_struct *item_ptr
+	editor_struct *editor, editor_item_struct *item_ptr
 );
 
 static void EditorFileSaveFormatHeader(
@@ -41,8 +41,8 @@ static void EditorFileSaveFormatHeader(
 	mp_header_struct *mp_header
 );
 static void EditorFileSaveFormatSection(
-        editor_struct *editor, editor_item_struct *item_ptr,
-        mp_section_struct *mp_section
+	editor_struct *editor, editor_item_struct *item_ptr,
+	mp_section_struct *mp_section
 );
 
 
@@ -56,8 +56,8 @@ int EditorFileSave(
 	GtkCTreeNode *branch	/* Save data on this branch. */
 );
 int EditorFileSaveAs(
-        editor_struct *editor, const char *filename,
-        GtkCTreeNode *branch    /* Save data on this branch. */
+	editor_struct *editor, const char *filename,
+	GtkCTreeNode *branch    /* Save data on this branch. */
 );
 
 
@@ -68,7 +68,7 @@ int EditorFileSaveAs(
  *	Updates the progress bar.
  */
 static int EditorFileLoadProgressCB(
-        long cur, long max, void *data
+	long cur, long max, void *data
 )
 {
 	gfloat percent;
@@ -92,22 +92,22 @@ static int EditorFileLoadProgressCB(
  *      Updates the progress bar.
  */
 static int EditorFileSaveProgressCB(
-        long cur, long max, void *data
+	long cur, long max, void *data
 )
 { 
-        gfloat percent;
-        editor_struct *editor = (editor_struct *)data;
-        if(editor == NULL)
-            return(0);
+	gfloat percent;
+	editor_struct *editor = (editor_struct *)data;
+	if(editor == NULL)
+	    return(0);
 
-        if(max > 0)
-            percent = (gfloat)cur / (gfloat)max;
-        else
-            percent = 1.0;
+	if(max > 0)
+	    percent = (gfloat)cur / (gfloat)max;
+	else
+	    percent = 1.0;
 
-        EditorSetStatusProgress(editor, percent);
+	EditorSetStatusProgress(editor, percent);
 
-        return(0);
+	return(0);
 }
 
 /*
@@ -138,7 +138,7 @@ static void EditorFileLoadParseTitleHeading(
 	line_next = line_ptr;
 	if((*line_next) == '"')
 	{
-            line_ptr++;
+	    line_ptr++;
 	    line_next++;
 	    while(((*line_next) != '"') && ((*line_next) != '\0'))
 	    {
@@ -171,185 +171,185 @@ static void EditorFileLoadParseTitleHeading(
 	/* Set new value. */
 	free(item_ptr->header_name);
 	item_ptr->header_name = tmp_buf;
-        /* Seek past current quote if any. */
-        if((*line_next) == '"')
-            line_next++;
-
-        /* Argument 2, section number. */
-        line_ptr = line_next;
-	while(ISBLANK(*line_ptr))
-	    line_ptr++;
-	line_next = line_ptr;
-        if((*line_next) == '"')
-        {
-            line_ptr++;
-            line_next++;         
-            while(((*line_next) != '"') && ((*line_next) != '\0'))
-            {
-                if((*line_next) == '\\')
-                {
-                    line_next++;
-                    if((*line_next) != '\0')
-                        line_next++;
-                }
-                else
-                {
-                    line_next++;
-                }
-            }
-        }
-        else      
-        {    
-            while(!ISBLANK(*line_next) && ((*line_next) != '\0'))
-                line_next++;
-        }
-        /* Allocate memory for new argument. */
-        tmp_buf_len = seg_len = MAX(line_next - line_ptr, 0);
-        tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-        if(tmp_buf != NULL)
-        {
-            if(tmp_buf_len > 0)
-                memcpy((void *)tmp_buf, (const void *)line_ptr, tmp_buf_len);
-            tmp_buf[tmp_buf_len] = '\0';
-        }
-        /* Set new value. */
-        free(item_ptr->header_section_number);
-        item_ptr->header_section_number = tmp_buf;
-        /* Seek past current quote if any. */
-        if((*line_next) == '"')
-            line_next++;
-
-        /* Argument 3, version. */
-        line_ptr = line_next;
-        while(ISBLANK(*line_ptr))
-            line_ptr++;
-        line_next = line_ptr;
-        if((*line_next) == '"')
-        {
-            line_ptr++;
-            line_next++;
-            while(((*line_next) != '"') && ((*line_next) != '\0'))
-            {       
-                if((*line_next) == '\\')
-                {
-                    line_next++;
-                    if((*line_next) != '\0')
-                        line_next++;
-                }
-                else
-                {
-                    line_next++;
-                }
-            }
-        }   
-        else
-        {   
-            while(!ISBLANK(*line_next) && ((*line_next) != '\0'))
-                line_next++;
-        }
-        /* Allocate memory for new argument. */
-        tmp_buf_len = seg_len = MAX(line_next - line_ptr, 0);
-        tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-        if(tmp_buf != NULL)
-        {
-            if(tmp_buf_len > 0)
-                memcpy((void *)tmp_buf, (const void *)line_ptr, tmp_buf_len);
-            tmp_buf[tmp_buf_len] = '\0';
-        }
-        /* Set new value. */
-        free(item_ptr->header_version);
-        item_ptr->header_version = tmp_buf;
 	/* Seek past current quote if any. */
 	if((*line_next) == '"')
 	    line_next++;
 
-        /* Argument 4, author. */
-        line_ptr = line_next;
-        while(ISBLANK(*line_ptr))
-            line_ptr++;
-        line_next = line_ptr;
-        if((*line_next) == '"')
-        {
+	/* Argument 2, section number. */
+	line_ptr = line_next;
+	while(ISBLANK(*line_ptr))
 	    line_ptr++;
-            line_next++;
-            while(((*line_next) != '"') && ((*line_next) != '\0'))
-            {
-                if((*line_next) == '\\')
-                {
-                    line_next++;
-                    if((*line_next) != '\0')
-                        line_next++;
-                }
-                else
-                {
-                    line_next++;
-                }
-            }
-        }   
-        else
-        {
-            while(!ISBLANK(*line_next) && ((*line_next) != '\0'))
-                line_next++;
-        }
-        /* Allocate memory for new argument. */
-        tmp_buf_len = seg_len = MAX(line_next - line_ptr, 0);
-        tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-        if(tmp_buf != NULL)
-        {
-            if(tmp_buf_len > 0)
-                memcpy((void *)tmp_buf, (const void *)line_ptr, tmp_buf_len);
-            tmp_buf[tmp_buf_len] = '\0';
-        }
-        /* Set new value. */
-        free(item_ptr->header_author);
-        item_ptr->header_author = tmp_buf;
-        /* Seek past current quote if any. */
-        if((*line_next) == '"')
-            line_next++;
+	line_next = line_ptr;
+	if((*line_next) == '"')
+	{
+	    line_ptr++;
+	    line_next++;         
+	    while(((*line_next) != '"') && ((*line_next) != '\0'))
+	    {
+		if((*line_next) == '\\')
+		{
+		    line_next++;
+		    if((*line_next) != '\0')
+			line_next++;
+		}
+		else
+		{
+		    line_next++;
+		}
+	    }
+	}
+	else      
+	{    
+	    while(!ISBLANK(*line_next) && ((*line_next) != '\0'))
+		line_next++;
+	}
+	/* Allocate memory for new argument. */
+	tmp_buf_len = seg_len = MAX(line_next - line_ptr, 0);
+	tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
+	if(tmp_buf != NULL)
+	{
+	    if(tmp_buf_len > 0)
+		memcpy((void *)tmp_buf, (const void *)line_ptr, tmp_buf_len);
+	    tmp_buf[tmp_buf_len] = '\0';
+	}
+	/* Set new value. */
+	free(item_ptr->header_section_number);
+	item_ptr->header_section_number = tmp_buf;
+	/* Seek past current quote if any. */
+	if((*line_next) == '"')
+	    line_next++;
 
-        /* Argument 5, catagory. */
-        line_ptr = line_next;
-        while(ISBLANK(*line_ptr))
-            line_ptr++;
-        line_next = line_ptr;
-        if((*line_next) == '"')
-        {
-            line_ptr++;
-            line_next++;
-            while(((*line_next) != '"') && ((*line_next) != '\0'))
-            {
-                if((*line_next) == '\\')
-                {
-                    line_next++;
-                    if((*line_next) != '\0')
-                        line_next++;
-                }
-                else
-                {
-                    line_next++;
-                }
-            }
-        }
-        else
-        {
-            while(!ISBLANK(*line_next) && ((*line_next) != '\0'))
-                line_next++;
-        }
-        /* Allocate memory for new argument. */
-        tmp_buf_len = seg_len = MAX(line_next - line_ptr, 0);
-        tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
-        if(tmp_buf != NULL)
-        {
-            if(tmp_buf_len > 0)
-                memcpy((void *)tmp_buf, (const void *)line_ptr, tmp_buf_len);
-            tmp_buf[tmp_buf_len] = '\0';
-        }
-        /* Set new value. */
-        free(item_ptr->header_catagory);
-        item_ptr->header_catagory = tmp_buf;
-        /* Seek past current quote if any. */
-        if((*line_next) == '"')
-            line_next++;
+	/* Argument 3, version. */
+	line_ptr = line_next;
+	while(ISBLANK(*line_ptr))
+	    line_ptr++;
+	line_next = line_ptr;
+	if((*line_next) == '"')
+	{
+	    line_ptr++;
+	    line_next++;
+	    while(((*line_next) != '"') && ((*line_next) != '\0'))
+	    {       
+		if((*line_next) == '\\')
+		{
+		    line_next++;
+		    if((*line_next) != '\0')
+			line_next++;
+		}
+		else
+		{
+		    line_next++;
+		}
+	    }
+	}   
+	else
+	{   
+	    while(!ISBLANK(*line_next) && ((*line_next) != '\0'))
+		line_next++;
+	}
+	/* Allocate memory for new argument. */
+	tmp_buf_len = seg_len = MAX(line_next - line_ptr, 0);
+	tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
+	if(tmp_buf != NULL)
+	{
+	    if(tmp_buf_len > 0)
+		memcpy((void *)tmp_buf, (const void *)line_ptr, tmp_buf_len);
+	    tmp_buf[tmp_buf_len] = '\0';
+	}
+	/* Set new value. */
+	free(item_ptr->header_version);
+	item_ptr->header_version = tmp_buf;
+	/* Seek past current quote if any. */
+	if((*line_next) == '"')
+	    line_next++;
+
+	/* Argument 4, author. */
+	line_ptr = line_next;
+	while(ISBLANK(*line_ptr))
+	    line_ptr++;
+	line_next = line_ptr;
+	if((*line_next) == '"')
+	{
+	    line_ptr++;
+	    line_next++;
+	    while(((*line_next) != '"') && ((*line_next) != '\0'))
+	    {
+		if((*line_next) == '\\')
+		{
+		    line_next++;
+		    if((*line_next) != '\0')
+			line_next++;
+		}
+		else
+		{
+		    line_next++;
+		}
+	    }
+	}   
+	else
+	{
+	    while(!ISBLANK(*line_next) && ((*line_next) != '\0'))
+		line_next++;
+	}
+	/* Allocate memory for new argument. */
+	tmp_buf_len = seg_len = MAX(line_next - line_ptr, 0);
+	tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
+	if(tmp_buf != NULL)
+	{
+	    if(tmp_buf_len > 0)
+		memcpy((void *)tmp_buf, (const void *)line_ptr, tmp_buf_len);
+	    tmp_buf[tmp_buf_len] = '\0';
+	}
+	/* Set new value. */
+	free(item_ptr->header_author);
+	item_ptr->header_author = tmp_buf;
+	/* Seek past current quote if any. */
+	if((*line_next) == '"')
+	    line_next++;
+
+	/* Argument 5, catagory. */
+	line_ptr = line_next;
+	while(ISBLANK(*line_ptr))
+	    line_ptr++;
+	line_next = line_ptr;
+	if((*line_next) == '"')
+	{
+	    line_ptr++;
+	    line_next++;
+	    while(((*line_next) != '"') && ((*line_next) != '\0'))
+	    {
+		if((*line_next) == '\\')
+		{
+		    line_next++;
+		    if((*line_next) != '\0')
+			line_next++;
+		}
+		else
+		{
+		    line_next++;
+		}
+	    }
+	}
+	else
+	{
+	    while(!ISBLANK(*line_next) && ((*line_next) != '\0'))
+		line_next++;
+	}
+	/* Allocate memory for new argument. */
+	tmp_buf_len = seg_len = MAX(line_next - line_ptr, 0);
+	tmp_buf = (char *)malloc((tmp_buf_len + 1) * sizeof(char));
+	if(tmp_buf != NULL)
+	{
+	    if(tmp_buf_len > 0)
+		memcpy((void *)tmp_buf, (const void *)line_ptr, tmp_buf_len);
+	    tmp_buf[tmp_buf_len] = '\0';
+	}
+	/* Set new value. */
+	free(item_ptr->header_catagory);
+	item_ptr->header_catagory = tmp_buf;
+	/* Seek past current quote if any. */
+	if((*line_next) == '"')
+	    line_next++;
 
 }
 
@@ -413,17 +413,17 @@ static void EditorFileLoadParseHeader(
 	    }
 	    /* Comment (dot backslash doublequote)? */
 	    else if(strpfx(line_ptr, ".\\\""))
-            {
+	    {
 		char *new_line_ptr;
 
-                /* Seek line_ptr to first and only argument. */
-                while(!ISBLANK(*line_ptr) &&
-                      ((*line_ptr) != '\0')
-                )
-                    line_ptr++;
+		/* Seek line_ptr to first and only argument. */
+		while(!ISBLANK(*line_ptr) &&
+		      ((*line_ptr) != '\0')
+		)
+		    line_ptr++;
 
-                while(ISBLANK(*line_ptr))
-                    line_ptr++;
+		while(ISBLANK(*line_ptr))
+		    line_ptr++;
 
 		/* Make a copy of the comment line as the new line. This
 		 * strips the comment sequence prefix and creates a
@@ -432,8 +432,8 @@ static void EditorFileLoadParseHeader(
 		 */
 		new_line_ptr = strdup(line_ptr);
 
-                /* Free old line. */
-                free((*line)[line_num]);
+		/* Free old line. */
+		free((*line)[line_num]);
 		line_ptr = NULL;
 
 		/* Set new line into line array. */
@@ -460,22 +460,22 @@ static void EditorFileLoadParseHeader(
  *	first as comments.
  */
 static void EditorFileSaveFormatHeader(
-        editor_struct *editor, editor_item_struct *item_ptr, 
-        mp_header_struct *mp_header
+	editor_struct *editor, editor_item_struct *item_ptr, 
+	mp_header_struct *mp_header
 )
 {
-        const char *line_ptr;
+	const char *line_ptr;
 	char *new_line_ptr;
-        int i, new_line_len;
+	int i, new_line_len;
 
 
-        if((editor == NULL) || (item_ptr == NULL) || (mp_header == NULL))
-            return;
+	if((editor == NULL) || (item_ptr == NULL) || (mp_header == NULL))
+	    return;
 
 	/* Delete any existing lines on manual page header structure
 	 * just in case.
 	 */
-	StringFreeArray(mp_header->line, mp_header->total_lines);
+	strlistfree(mp_header->line, mp_header->total_lines);
 	mp_header->line = NULL;
 	mp_header->total_lines = 0;
 
@@ -522,18 +522,18 @@ static void EditorFileSaveFormatHeader(
 	    strlen((item_ptr->header_name == NULL) ?
 		"(null)" : item_ptr->header_name
 	    ) + 2 +
-            strlen((item_ptr->header_section_number == NULL) ?
-                "(null)" : item_ptr->header_section_number
-            ) + 2 +
-            strlen((item_ptr->header_version == NULL) ?
-                "(null)" : item_ptr->header_version
-            ) + 2 +
-            strlen((item_ptr->header_author == NULL) ?
-                "(null)" : item_ptr->header_author
-            ) + 2 +
-            strlen((item_ptr->header_catagory == NULL) ?
-                "(null)" : item_ptr->header_catagory
-            ) + 2;
+	    strlen((item_ptr->header_section_number == NULL) ?
+		"(null)" : item_ptr->header_section_number
+	    ) + 2 +
+	    strlen((item_ptr->header_version == NULL) ?
+		"(null)" : item_ptr->header_version
+	    ) + 2 +
+	    strlen((item_ptr->header_author == NULL) ?
+		"(null)" : item_ptr->header_author
+	    ) + 2 +
+	    strlen((item_ptr->header_catagory == NULL) ?
+		"(null)" : item_ptr->header_catagory
+	    ) + 2;
 	new_line_ptr = (char *)malloc((new_line_len + 1) * sizeof(char));
 	if(new_line_ptr != NULL)
 	{
@@ -574,57 +574,57 @@ static void EditorFileSaveFormatHeader(
  *	Section name will be coppied as well.
  */
 static void EditorFileSaveFormatSection(
-        editor_struct *editor, editor_item_struct *item_ptr,
-        mp_section_struct *mp_section
+	editor_struct *editor, editor_item_struct *item_ptr,
+	mp_section_struct *mp_section
 )
 {
-        const char *line_ptr;
-        char *new_line_ptr;
-        int i;
+	const char *line_ptr;
+	char *new_line_ptr;
+	int i;
 
 
-        if((editor == NULL) || (item_ptr == NULL) || (mp_section == NULL))
-            return;
+	if((editor == NULL) || (item_ptr == NULL) || (mp_section == NULL))
+	    return;
 
-        /* Delete any existing lines on manual page section structure
-         * just in case.
-         */
-        StringFreeArray(mp_section->line, mp_section->total_lines);
-        mp_section->line = NULL;
-        mp_section->total_lines = 0;
-        
-         
-        /* Allocate lines pointer array on manual page section structure
-         * to match all lines on item data structure.
-         */
-        mp_section->total_lines = item_ptr->total_lines;
-        if(mp_section->total_lines > 0)
-        {
-            mp_section->line = (char **)calloc(
-                mp_section->total_lines, sizeof(char *)
-            );
-            if(mp_section->line == NULL)
-            {
-                mp_section->total_lines = 0;
-                return;
-            }
-        }
+	/* Delete any existing lines on manual page section structure
+	 * just in case.
+	 */
+	strlistfree(mp_section->line, mp_section->total_lines);
+	mp_section->line = NULL;
+	mp_section->total_lines = 0;
+	
+	 
+	/* Allocate lines pointer array on manual page section structure
+	 * to match all lines on item data structure.
+	 */
+	mp_section->total_lines = item_ptr->total_lines;
+	if(mp_section->total_lines > 0)
+	{
+	    mp_section->line = (char **)calloc(
+		mp_section->total_lines, sizeof(char *)
+	    );
+	    if(mp_section->line == NULL)
+	    {
+		mp_section->total_lines = 0;
+		return;
+	    }
+	}
 
-        /* First copy each line on the item data structure to the manual
-         * page section structure.
-         */
-        for(i = 0; i < item_ptr->total_lines; i++)
-        {
-            line_ptr = (const char *)item_ptr->line[i];
-            if(line_ptr == NULL)
-                continue;
-            
-            /* Create new line. */
+	/* First copy each line on the item data structure to the manual
+	 * page section structure.
+	 */
+	for(i = 0; i < item_ptr->total_lines; i++)
+	{
+	    line_ptr = (const char *)item_ptr->line[i];
+	    if(line_ptr == NULL)
+		continue;
+	    
+	    /* Create new line. */
 	    new_line_ptr = strdup(line_ptr);
 
-            /* Set new line to manual page section structure line array. */
-            mp_section->line[i] = new_line_ptr;
-        }
+	    /* Set new line to manual page section structure line array. */
+	    mp_section->line[i] = new_line_ptr;
+	}
 
 	/* Copy section name. */
 	if(item_ptr->section_name != NULL)
@@ -659,7 +659,7 @@ static void EditorFileSaveFormatSection(
  */
 int EditorFileLoad(
 	editor_struct *editor, const char *filename,
-        GtkCTreeNode *branch,	/* Insert after this toplevel trunk. */
+	GtkCTreeNode *branch,	/* Insert after this toplevel trunk. */
 	gbool as_template
 )
 {
@@ -700,11 +700,11 @@ int EditorFileLoad(
 	pixmaps_list = &core_ptr->pixmaps_list;
 
 
-        /* Be sure to apply values of currently selected branch (not
-         * the given branch) before opening. This ensures we have data
-         * up to date before loading new data.
-         */
-        EditorDoApplyValues(editor, editor->selected_branch);
+	/* Be sure to apply values of currently selected branch (not
+	 * the given branch) before opening. This ensures we have data
+	 * up to date before loading new data.
+	 */
+	EditorDoApplyValues(editor, editor->selected_branch);
 
 
 	/* Find branch node to insert after. */
@@ -742,8 +742,8 @@ int EditorFileLoad(
 
 	/* Mark editor as processing. */
 	editor->processing = TRUE;
-        EditorSetBusy(editor);
-        EditorSetStatusMessage(editor, "Loading manual page...");
+	EditorSetBusy(editor);
+	EditorSetStatusMessage(editor, "Loading manual page...");
 
 
 	/* Load manual page file. */
@@ -760,23 +760,23 @@ int EditorFileLoad(
 	{
 	    /* Error occured while loading. */
 
-            /* Deallocate loaded header if any. */
-            MPDeleteHeader(mp_header);
-            mp_header = NULL;
+	    /* Deallocate loaded header if any. */
+	    MPDeleteHeader(mp_header);
+	    mp_header = NULL;
 
-            /* Deallocate loaded sections if any. */
-            MPDeleteAllSections(mp_section, total_mp_sections);
-            mp_section = NULL;
-            total_mp_sections = 0;
+	    /* Deallocate loaded sections if any. */
+	    MPDeleteAllSections(mp_section, total_mp_sections);
+	    mp_section = NULL;
+	    total_mp_sections = 0;
 
-            EditorSetStatusMessage(editor, "Loading done");
-            EditorSetStatusProgress(editor, 0.0);
+	    EditorSetStatusMessage(editor, "Loading done");
+	    EditorSetStatusProgress(editor, 0.0);
 
-            /* Update menus. */
-            EditorUpdateMenus(editor);
+	    /* Update menus. */
+	    EditorUpdateMenus(editor);
 
 	    editor->processing = FALSE;
-            EditorSetReady(editor);   
+	    EditorSetReady(editor);   
 
 	    return(status);
 	}
@@ -814,9 +814,9 @@ int EditorFileLoad(
 		text[0] = tmp_path;
 
 		/* Create new trunk, insert before trunk which is the
-                 * sibling of the toplevel trunk of given branch and
-                 * may be NULL.
-                 */
+		 * sibling of the toplevel trunk of given branch and
+		 * may be NULL.
+		 */
 		new_trunk = branch = gtk_ctree_insert_node(
 		    ctree,
 		    NULL,		/* No parent, it's toplevel. */
@@ -825,8 +825,8 @@ int EditorFileLoad(
 		    MEDIT_LIST_ICON_TEXT_SPACING,
 		    pixmaps_list->manual_closed_20x20,
 		    pixmaps_list->manual_closed_20x20_mask,
-                    pixmaps_list->manual_opened_20x20,
-                    pixmaps_list->manual_opened_20x20_mask,
+		    pixmaps_list->manual_opened_20x20,
+		    pixmaps_list->manual_opened_20x20_mask,
 		    FALSE,		/* Is leaf. */
 		    TRUE		/* Expanded. */
 		);
@@ -834,7 +834,7 @@ int EditorFileLoad(
 		trunk = branch;
 
 		/* Create editor item structure. */
-                editor_item_ptr = EditorItemNew(
+		editor_item_ptr = EditorItemNew(
 		    EditorItemTypeFile,
 		    editor,
 		    ctree,
@@ -858,7 +858,7 @@ int EditorFileLoad(
 			    core_ptr->untitled_count
 			);
 			free(editor_item_ptr->file_name);
-                        editor_item_ptr->file_name = strdup(untitled_title);
+			editor_item_ptr->file_name = strdup(untitled_title);
 
 			/* Mark as having changes. */
 			editor_item_ptr->has_changes = TRUE;
@@ -887,8 +887,8 @@ int EditorFileLoad(
 		    editor_item_ptr, EditorItemDestroyCB
 		);
 
-                free(tmp_path);         /* Deallocate coppied tmp_path. */
-                tmp_path = NULL;
+		free(tmp_path);         /* Deallocate coppied tmp_path. */
+		tmp_path = NULL;
 		text[0] = NULL;
 
 		/* Add header as first leaf. */
@@ -987,35 +987,35 @@ int EditorFileLoad(
 			text[0] = mp_section_ptr->section;
 		    }
 		    /* Insert new branch to layout ctree. */
-                    branch = gtk_ctree_insert_node(
-                        ctree, trunk, NULL,
-                        text,
-                        MEDIT_LIST_ICON_TEXT_SPACING,
-                        pixmaps_list->manpage_section_20x20,
-                        pixmaps_list->manpage_section_20x20_mask,
-                        pixmaps_list->manpage_section_20x20,
-                        pixmaps_list->manpage_section_20x20_mask,
+		    branch = gtk_ctree_insert_node(
+			ctree, trunk, NULL,
+			text,
+			MEDIT_LIST_ICON_TEXT_SPACING,
+			pixmaps_list->manpage_section_20x20,
+			pixmaps_list->manpage_section_20x20_mask,
+			pixmaps_list->manpage_section_20x20,
+			pixmaps_list->manpage_section_20x20_mask,
 			TRUE,		/* Is leaf. */
 			FALSE		/* Expanded. */
 		    );
 
-                    /* Create new editor item structure. */  
-                    editor_item_ptr = EditorItemNew(
-                        EditorItemTypeSection,
-                        editor,
-                        ctree,
-                        trunk,		/* Parent. */
-                        branch,		/* This branch. */
-                        TRUE,		/* Is leaf. */
-                        mp_section_ptr->line,
-                        mp_section_ptr->total_lines
-                    );
+		    /* Create new editor item structure. */  
+		    editor_item_ptr = EditorItemNew(
+			EditorItemTypeSection,
+			editor,
+			ctree,
+			trunk,		/* Parent. */
+			branch,		/* This branch. */
+			TRUE,		/* Is leaf. */
+			mp_section_ptr->line,
+			mp_section_ptr->total_lines
+		    );
 
-                    /* Section's lines are transfered, so mark them
+		    /* Section's lines are transfered, so mark them
 		     * NULL and 0 on the source.
 		     */
-                    mp_section_ptr->line = NULL;
-                    mp_section_ptr->total_lines = 0;
+		    mp_section_ptr->line = NULL;
+		    mp_section_ptr->total_lines = 0;
 
 		    if(editor_item_ptr != NULL)
 		    {
@@ -1025,11 +1025,11 @@ int EditorFileLoad(
 			);
 		    }
 
-                    /* Set branch data as new editor_item_struct. */
-                    EditorBranchSetData(
-                        ctree, branch,
+		    /* Set branch data as new editor_item_struct. */
+		    EditorBranchSetData(
+			ctree, branch,
 			editor_item_ptr, EditorItemDestroyCB
-                    );
+		    );
 
 		    free(tmp_text);	/* Free tempory text. */
 		    tmp_text = NULL;
@@ -1038,7 +1038,7 @@ int EditorFileLoad(
 	    }
 	}
 
-        EditorSetStatusMessage(editor, "Load: Post processing...");
+	EditorSetStatusMessage(editor, "Load: Post processing...");
 
 	/* Deallocate loaded header if any. */
 	MPDeleteHeader(mp_header);
@@ -1081,14 +1081,14 @@ int EditorFileLoad(
 	/* Mark processing done. */
 	editor->processing = FALSE;
 
-        /* Force select new trunk, new_trunk is the toplevel trunk
-         * node for this newly loaded file (do this after processing
+	/* Force select new trunk, new_trunk is the toplevel trunk
+	 * node for this newly loaded file (do this after processing
 	 * is marked done).
-         */
+	 */
 	if(new_trunk != NULL)
 	    EditorBranchSelect(editor, new_trunk);
 
-        EditorSetReady(editor);
+	EditorSetReady(editor);
 
 	return(0);
 }
@@ -1118,17 +1118,17 @@ int EditorFileSave(
 {
 	int i, status;
 	const char *filename = NULL;
-        mp_header_struct *mp_header;
-        mp_section_struct **mp_section, *mp_section_ptr;
-        int total_mp_sections;
-        GtkCTree *ctree;
-        GtkCTreeNode *trunk;
-        editor_item_struct *item_ptr;
-        medit_core_struct *core_ptr;
+	mp_header_struct *mp_header;
+	mp_section_struct **mp_section, *mp_section_ptr;
+	int total_mp_sections;
+	GtkCTree *ctree;
+	GtkCTreeNode *trunk;
+	editor_item_struct *item_ptr;
+	medit_core_struct *core_ptr;
 
 
-        if((editor == NULL) || (branch == NULL))
-            return(-1);
+	if((editor == NULL) || (branch == NULL))
+	    return(-1);
 
 	if(!editor->initialized)
 	    return(-1);
@@ -1137,13 +1137,13 @@ int EditorFileSave(
 	if(editor->processing)
 	    return(-1);
 
-        ctree = (GtkCTree *)editor->layout_ctree;
-        if(ctree == NULL)
-            return(-1);
+	ctree = (GtkCTree *)editor->layout_ctree;
+	if(ctree == NULL)
+	    return(-1);
 
-        core_ptr = (medit_core_struct *)editor->core_ptr;
-        if(core_ptr == NULL)
-            return(-1);
+	core_ptr = (medit_core_struct *)editor->core_ptr;
+	if(core_ptr == NULL)
+	    return(-1);
 
 	/* Be sure to apply values of currently selected branch (not
 	 * the given branch) before saving. This ensures we save the most
@@ -1211,7 +1211,7 @@ different path.",
 		    tmp_buf = NULL;
 
 		    return(-2);
-                }
+		}
 	    }
 	}
 
@@ -1220,8 +1220,8 @@ different path.",
 	editor->processing = TRUE;
 	EditorSetBusy(editor);
 
-        EditorSetStatusMessage(editor, "Formatting data...");
-        EditorSetStatusProgress(editor, 0.0);
+	EditorSetStatusMessage(editor, "Formatting data...");
+	EditorSetStatusProgress(editor, 0.0);
 
 
 	/* Start on the trunk's first child and itterate through its
@@ -1232,8 +1232,8 @@ different path.",
 	{
 	    GtkCTreeRow *node_row;
 
-            node_row = GTK_CTREE_ROW(trunk);
-            if(node_row != NULL)
+	    node_row = GTK_CTREE_ROW(trunk);
+	    if(node_row != NULL)
 		branch = node_row->children;
 	}
 
@@ -1245,9 +1245,9 @@ different path.",
 	{
 	    GtkCTreeRow *node_row;
 
-            item_ptr = EditorBranchGetData(ctree, branch);
-            if(item_ptr != NULL)
-            {
+	    item_ptr = EditorBranchGetData(ctree, branch);
+	    if(item_ptr != NULL)
+	    {
 		/* Handle item data by type. */
 		switch(item_ptr->type)
 		{
@@ -1261,17 +1261,17 @@ different path.",
 		    );
 		    if(mp_header != NULL)
 		    {
-                        /* Copy values from the item data structure
+			/* Copy values from the item data structure
 			 * to the manual page header structure formatted.
 			 */
-                        EditorFileSaveFormatHeader(
-                            editor, item_ptr, mp_header
-                        );
+			EditorFileSaveFormatHeader(
+			    editor, item_ptr, mp_header
+			);
 		    }
 		    break;
 
-                  case EditorItemTypeSection:
-                    /* Allocate a new section structure. */
+		  case EditorItemTypeSection:
+		    /* Allocate a new section structure. */
 
 		    mp_section_ptr = NULL;
 
@@ -1280,14 +1280,14 @@ different path.",
 			total_mp_sections = 0;
 		    i = total_mp_sections;
 		    total_mp_sections = i + 1;
-                    mp_section = (mp_section_struct **)realloc(
-                        mp_section,
+		    mp_section = (mp_section_struct **)realloc(
+			mp_section,
 			total_mp_sections * sizeof(mp_section_struct *)
-                    );
-                    if(mp_section == NULL)
-                    {
+		    );
+		    if(mp_section == NULL)
+		    {
 			total_mp_sections = 0;   
-                    }
+		    }
 		    else
 		    {
 			/* Allocate new section. */
@@ -1299,29 +1299,29 @@ different path.",
 		    /* Successfully allocated a new section? */
 		    if(mp_section_ptr != NULL)
 		    {
-                        /* Copy values from the item data structure
-                         * to the manual page section structure formatted.
-                         */
-                        EditorFileSaveFormatSection(
-                            editor, item_ptr, mp_section_ptr
-                        );
+			/* Copy values from the item data structure
+			 * to the manual page section structure formatted.
+			 */
+			EditorFileSaveFormatSection(
+			    editor, item_ptr, mp_section_ptr
+			);
 		    }
-                    break;
-        
+		    break;
+	
 
 		}
 	    }
 
 	    /* Get sibling of branch. */
 	    node_row = GTK_CTREE_ROW(branch);
-            if(node_row == NULL)
+	    if(node_row == NULL)
 		branch = NULL;
 	    else
-                branch = node_row->sibling;
+		branch = node_row->sibling;
 	}
 
 
-        EditorSetStatusMessage(editor, "Saving data...");
+	EditorSetStatusMessage(editor, "Saving data...");
 
 	/* Save to file. */
 	status = MPSave(
@@ -1340,18 +1340,18 @@ different path.",
 	total_mp_sections = 0;
 
 
-        EditorSetStatusMessage(editor, "Saving done");
-        EditorSetStatusProgress(editor, 0.0);
+	EditorSetStatusMessage(editor, "Saving done");
+	EditorSetStatusProgress(editor, 0.0);
 
 
 
-        /* Do not update last saved path. */
+	/* Do not update last saved path. */
 
-        /* Update menus. */
-        EditorUpdateMenus(editor);
+	/* Update menus. */
+	EditorUpdateMenus(editor);
 
 	editor->processing = FALSE;
-        EditorSetReady(editor);
+	EditorSetReady(editor);
 
 	return(status);
 }
@@ -1367,8 +1367,8 @@ different path.",
  *	overwrite.
  */
 int EditorFileSaveAs(
-        editor_struct *editor, const char *filename,
-        GtkCTreeNode *branch    /* Save data on this branch. */
+	editor_struct *editor, const char *filename,
+	GtkCTreeNode *branch    /* Save data on this branch. */
 )
 {
 	int status;
@@ -1376,60 +1376,60 @@ int EditorFileSaveAs(
 	char *tmp_buf;
 	int tmp_buf_len;
 	const char *cstrptr;
-        GtkCTree *ctree;
+	GtkCTree *ctree;
 	GtkCTreeRow *branch_row;
-        GtkCTreeNode *trunk;
-        editor_item_struct *item_ptr;
-        medit_core_struct *core_ptr;
+	GtkCTreeNode *trunk;
+	editor_item_struct *item_ptr;
+	medit_core_struct *core_ptr;
 	medit_pixmaps_list_struct *pixmaps_list;
 	struct stat stat_buf;
 
 
-        if((editor == NULL) || (branch == NULL) || (filename == NULL))
-            return(-1);
+	if((editor == NULL) || (branch == NULL) || (filename == NULL))
+	    return(-1);
 
 	if(!editor->initialized)
 	    return(-1);
 
-        ctree = (GtkCTree *)editor->layout_ctree;
-        if(ctree == NULL) 
-            return(-1);
+	ctree = (GtkCTree *)editor->layout_ctree;
+	if(ctree == NULL) 
+	    return(-1);
 
-        core_ptr = (medit_core_struct *)editor->core_ptr;
-        if(core_ptr == NULL)
-            return(-1);
+	core_ptr = (medit_core_struct *)editor->core_ptr;
+	if(core_ptr == NULL)
+	    return(-1);
 
 	pixmaps_list = &core_ptr->pixmaps_list;
 
-        /* Find toplevel trunk branch of the given branch which will
-         * be the one to save data from.
-         */
-        trunk = NULL;
-        if(branch != NULL)
-        {
-            GtkCTreeRow *node_row;
-            GtkCTreeNode *next_node;  
-        
-            /* Start from given branch and itterate to toplevel. */
-            next_node = branch;
-            while(1)
-            {
-                node_row = GTK_CTREE_ROW(next_node);
-                if(node_row == NULL)
-                {
-                    break;
-                }
-                else if(node_row->parent == NULL)
-                {
-                    trunk = next_node;
-                    break;
-                }
-                else
-                {
-                    next_node = node_row->parent;
-                }
-            }
-        }
+	/* Find toplevel trunk branch of the given branch which will
+	 * be the one to save data from.
+	 */
+	trunk = NULL;
+	if(branch != NULL)
+	{
+	    GtkCTreeRow *node_row;
+	    GtkCTreeNode *next_node;  
+	
+	    /* Start from given branch and itterate to toplevel. */
+	    next_node = branch;
+	    while(1)
+	    {
+		node_row = GTK_CTREE_ROW(next_node);
+		if(node_row == NULL)
+		{
+		    break;
+		}
+		else if(node_row->parent == NULL)
+		{
+		    trunk = next_node;
+		    break;
+		}
+		else
+		{
+		    next_node = node_row->parent;
+		}
+	    }
+	}
 	if(trunk == NULL)
 	    return(-1);
 
@@ -1460,26 +1460,26 @@ file. If you say yes then any existing data on the file\n\
 will be replaced with the data you are intending to save.\n\
 This new data may not correspond to the data in the existing\n\
 file, if you are unsure say cancel.",
-                CDIALOG_ICON_WARNING,
-                CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_CANCEL |
-                CDIALOG_BTNFLAG_HELP,
-                CDIALOG_BTNFLAG_CANCEL
-            );
+		CDIALOG_ICON_WARNING,
+		CDIALOG_BTNFLAG_YES | CDIALOG_BTNFLAG_CANCEL |
+		CDIALOG_BTNFLAG_HELP,
+		CDIALOG_BTNFLAG_CANCEL
+	    );
 
 	    /* Free message buffer. */
 	    free(tmp_buf);
 	    tmp_buf = NULL;
 
-            switch(status)
-            {
-              case CDIALOG_RESPONSE_YES:
-              case CDIALOG_RESPONSE_YES_TO_ALL:
-              case CDIALOG_RESPONSE_OK:
-                break;
+	    switch(status)
+	    {
+	      case CDIALOG_RESPONSE_YES:
+	      case CDIALOG_RESPONSE_YES_TO_ALL:
+	      case CDIALOG_RESPONSE_OK:
+		break;
 
-              default:
-                return(-3);
-                break;
+	      default:
+		return(-3);
+		break;
 	    }
 	}
 
@@ -1502,8 +1502,8 @@ file, if you are unsure say cancel.",
 	    cstrptr += 1;	/* Seek past deliminator. */
 
 	    free(item_ptr->file_name);
-            item_ptr->file_name = strdup(cstrptr);
-        }
+	    item_ptr->file_name = strdup(cstrptr);
+	}
 	/* Update toplevel trunk branch name. */
 	if(item_ptr->file_name != NULL)
 	{
@@ -1513,24 +1513,24 @@ file, if you are unsure say cancel.",
 		gtk_ctree_node_set_pixtext(
 		    ctree,
 		    branch,
-                    0,              /* Column. */
+		    0,              /* Column. */
 		    item_ptr->file_name,
 		    MEDIT_LIST_ICON_TEXT_SPACING,
-                    pixmaps_list->manual_opened_20x20,
-                    pixmaps_list->manual_opened_20x20_mask
-                );
+		    pixmaps_list->manual_opened_20x20,
+		    pixmaps_list->manual_opened_20x20_mask
+		);
 	    }
 	    else
 	    {
-                gtk_ctree_node_set_pixtext(
-                    ctree,
-                    branch,
-                    0,              /* Column. */
-                    item_ptr->file_name,
-                    MEDIT_LIST_ICON_TEXT_SPACING,
-                    pixmaps_list->manual_closed_20x20,
-                    pixmaps_list->manual_closed_20x20_mask
-                );
+		gtk_ctree_node_set_pixtext(
+		    ctree,
+		    branch,
+		    0,              /* Column. */
+		    item_ptr->file_name,
+		    MEDIT_LIST_ICON_TEXT_SPACING,
+		    pixmaps_list->manual_closed_20x20,
+		    pixmaps_list->manual_closed_20x20_mask
+		);
 	    }
 	}
 
@@ -1538,15 +1538,15 @@ file, if you are unsure say cancel.",
 	/* Call save procedure. */
 	status = EditorFileSave(editor, trunk);
 
-        /* Update last opened path. */
-        free(editor->last_save_as_path);
-        editor->last_save_as_path = strdup(filename);
-        if(editor->last_save_as_path != NULL)
-        {
-            strptr = strrchr(editor->last_save_as_path, DIR_DELIMINATOR);
-            if(strptr != NULL)
-                (*strptr) = '\0';
-        }
+	/* Update last opened path. */
+	free(editor->last_save_as_path);
+	editor->last_save_as_path = strdup(filename);
+	if(editor->last_save_as_path != NULL)
+	{
+	    strptr = strrchr(editor->last_save_as_path, DIR_DELIMINATOR);
+	    if(strptr != NULL)
+		(*strptr) = '\0';
+	}
 
 	return(status);
 }
