@@ -1432,7 +1432,7 @@ void MPDeleteHeader(mp_header_struct *mp_header)
 
 	free(mp_header->title);
 
-	StringFreeArray(mp_header->line, mp_header->total_lines);
+	strlistfree(mp_header->line, mp_header->total_lines);
 
 	free(mp_header);
 }
@@ -1459,7 +1459,7 @@ void MPDeleteAllSections(
 
 	    free(mp_section_ptr->section);
 
-	    StringFreeArray(
+	    strlistfree(
 		mp_section_ptr->line,
 		mp_section_ptr->total_lines
 	    );
