@@ -649,7 +649,7 @@ int PrefLoadFromFile(pref_struct *pref, const char *filename)
 			gtk_clist_append(clist, (gchar **)strv);
 
 		    /* Deallocate exploded strings. */
-		    StringFreeArray(strv, strc);
+		    strlistfree(strv, strc);
 		    strv = NULL;
 		    strc = 0;
                 }
